# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`galera`](#galera): Installs MySQL/MariaDB with galera cluster plugin
* [`galera::firewall`](#galerafirewall): Open firewall ports used by galera using puppetlabs-firewall.

#### Private Classes

* `galera::arbitrator`: Installs and configures the Arbitrator service.
* `galera::debian`: Adds workarounds to solve issues specific to Debian-based systems.
* `galera::redhat`: Adds workarounds to solve issues specific to RedHat-based systems.
* `galera::repo`: Evaluates which repositories should be enabled depending on $vendor_type and $vendor_version.
* `galera::status`: Configures a user and script that will check the status of the galera cluster.
* `galera::validate`: Validate that the cluster can accept connections at the point where
the `mysql::server` resource is marked as complete.
This is used because after returning success, the service is still not quite ready.

### Defined types

#### Public Defined types


#### Private Defined types

* `galera::repo::config`: Configures a APT or YUM repository.

## Classes

### <a name="galera"></a>`galera`

Installs MySQL/MariaDB with galera cluster plugin

#### Parameters

The following parameters are available in the `galera` class:

* [`additional_packages`](#additional_packages)
* [`arbitrator`](#arbitrator)
* [`arbitrator_config_file`](#arbitrator_config_file)
* [`arbitrator_log_file`](#arbitrator_log_file)
* [`arbitrator_options`](#arbitrator_options)
* [`arbitrator_package_ensure`](#arbitrator_package_ensure)
* [`arbitrator_package_name`](#arbitrator_package_name)
* [`arbitrator_service_enabled`](#arbitrator_service_enabled)
* [`arbitrator_service_name`](#arbitrator_service_name)
* [`arbitrator_template`](#arbitrator_template)
* [`bind_address`](#bind_address)
* [`bootstrap_command`](#bootstrap_command)
* [`client_package_name`](#client_package_name)
* [`cluster_name`](#cluster_name)
* [`configure_firewall`](#configure_firewall)
* [`configure_repo`](#configure_repo)
* [`create_root_my_cnf`](#create_root_my_cnf)
* [`create_root_user`](#create_root_user)
* [`create_status_user`](#create_status_user)
* [`deb_sysmaint_password`](#deb_sysmaint_password)
* [`default_options`](#default_options)
* [`epel_needed`](#epel_needed)
* [`galera_master`](#galera_master)
* [`galera_package_ensure`](#galera_package_ensure)
* [`galera_package_name`](#galera_package_name)
* [`galera_servers`](#galera_servers)
* [`libgalera_location`](#libgalera_location)
* [`local_ip`](#local_ip)
* [`manage_additional_packages`](#manage_additional_packages)
* [`mysql_package_name`](#mysql_package_name)
* [`mysql_port`](#mysql_port)
* [`mysql_restart`](#mysql_restart)
* [`mysql_service_name`](#mysql_service_name)
* [`override_options`](#override_options)
* [`override_repos`](#override_repos)
* [`package_ensure`](#package_ensure)
* [`purge_conf_dir`](#purge_conf_dir)
* [`root_password`](#root_password)
* [`rundir`](#rundir)
* [`service_enabled`](#service_enabled)
* [`status_allow`](#status_allow)
* [`status_available_when_donor`](#status_available_when_donor)
* [`status_available_when_readonly`](#status_available_when_readonly)
* [`status_check`](#status_check)
* [`status_host`](#status_host)
* [`status_log_on_failure`](#status_log_on_failure)
* [`status_log_on_success`](#status_log_on_success)
* [`status_log_on_success_operator`](#status_log_on_success_operator)
* [`status_password`](#status_password)
* [`status_port`](#status_port)
* [`status_user`](#status_user)
* [`validate_connection`](#validate_connection)
* [`vendor_type`](#vendor_type)
* [`vendor_version`](#vendor_version)
* [`wsrep_group_comm_port`](#wsrep_group_comm_port)
* [`wsrep_inc_state_transfer_port`](#wsrep_inc_state_transfer_port)
* [`wsrep_sst_auth`](#wsrep_sst_auth)
* [`wsrep_sst_method`](#wsrep_sst_method)
* [`wsrep_state_transfer_port`](#wsrep_state_transfer_port)

##### <a name="additional_packages"></a>`additional_packages`

Data type: `Optional[Array]`

Specifies a list of additional packages that may be required for SST and
other features. The module automatically discovers all additional packages
that are required for the selected vendor/sst, but this parameter can be
used to overwrite the discovered package list.
Default: A vendor-, version- and OS-specific value.

Default value: ``undef``

##### <a name="arbitrator"></a>`arbitrator`

Data type: `Boolean`

Specifies whether this node should run Galera Arbitrator instead of a
MySQL/MariaDB server.

##### <a name="arbitrator_config_file"></a>`arbitrator_config_file`

Data type: `Optional[String]`

Specifies the configuration file for the Arbitrator service.
Default: A vendor-, version- and OS-specific value.

Default value: ``undef``

##### <a name="arbitrator_log_file"></a>`arbitrator_log_file`

Data type: `Optional[String]`

Specifies the optional log file for the Arbitrator service.
By default it logs to syslog.

Default value: ``undef``

##### <a name="arbitrator_options"></a>`arbitrator_options`

Data type: `String`

Specifies configuration options for the Arbitrator service.

##### <a name="arbitrator_package_ensure"></a>`arbitrator_package_ensure`

Data type: `String`

Specifies the ensure state for the Arbitrator package.
Valid options: all values supported by the package type.
Default: `present`

##### <a name="arbitrator_package_name"></a>`arbitrator_package_name`

Data type: `Optional[String]`

Specifies the name of the Arbitrator package to install.
Default: A vendor-, version- and OS-specific value.

Default value: ``undef``

##### <a name="arbitrator_service_enabled"></a>`arbitrator_service_enabled`

Data type: `Boolean`

Specifies whether the Arbitrator service should be enabled.
Expects that `$arbitrator` is also set to `true`.
Default: `true`

##### <a name="arbitrator_service_name"></a>`arbitrator_service_name`

Data type: `Optional[String]`

Specifies the name of the Arbitrator service.
Default: A vendor-, version- and OS-specific value.

Default value: ``undef``

##### <a name="arbitrator_template"></a>`arbitrator_template`

Data type: `String`

Specifies the template to use when creating `$arbitrator_config_file`.

##### <a name="bind_address"></a>`bind_address`

Data type: `String`

Specifies the IP address to bind MySQL/MariaDB to. The module expects the
server to listen on localhost for proper operation. Default: `::`

##### <a name="bootstrap_command"></a>`bootstrap_command`

Data type: `Optional[String]`

Specifies a command used to bootstrap the galera cluster.
Default: A vendor-, version- and OS-specific bootstrap command.

Default value: ``undef``

##### <a name="client_package_name"></a>`client_package_name`

Data type: `Optional[String]`

Specifies the name of the MySQL/MariaDB client package to install.
Default: A vendor-, version- and OS-specific value.

Default value: ``undef``

##### <a name="cluster_name"></a>`cluster_name`

Data type: `String`

Specifies the name of the cluster and should be identical on all nodes.
This must be set for the module to work properly (although galera does
not require this value.)

##### <a name="configure_firewall"></a>`configure_firewall`

Data type: `Boolean`

Specifies whether to open firewall ports used by galera using
puppetlabs-firewall. Default: `true`

##### <a name="configure_repo"></a>`configure_repo`

Data type: `Boolean`

Specifies whether to configure additional repositories that are required for
installing galera. Default: `true`

##### <a name="create_root_my_cnf"></a>`create_root_my_cnf`

Data type: `Boolean`

A flag to indicate if we should manage the root .my.cnf. Set this to false
if you wish to manage your root .my.cnf file elsewhere. Default: `true`

##### <a name="create_root_user"></a>`create_root_user`

Data type: `Optional[Boolean]`

A flag to indicate if we should manage the root user. Set this to false if
you wish to manage your root user elsewhere. If this is set to `undef`, the
module will use `true` if this node is `$galera_master`. Default: `undef`

Default value: ``undef``

##### <a name="create_status_user"></a>`create_status_user`

Data type: `Boolean`

A flag to indicate if we should manage the status user. Set this to false
if you wish to manage your status user elsewhere. Default: `true`

##### <a name="deb_sysmaint_password"></a>`deb_sysmaint_password`

Data type: `String`

Specifies the password to set on Debian/Ubuntu for the sysmaint user used
during updates. Default: `sysmaint`

##### <a name="default_options"></a>`default_options`

Data type: `Hash`

Internal parameter, *do NOT change!* Use `$override_options` to customize
MySQL options.

##### <a name="epel_needed"></a>`epel_needed`

Data type: `Boolean`

Specifies whether or not the EPEL repository should be enabled on
RedHat-based systems. This is required for certain vendors and SST methods
to install packages such as socat.
Default: `true`

##### <a name="galera_master"></a>`galera_master`

Data type: `String`

Specifies the node that will bootstrap the cluster if all nodes go down.
Default: `$fqdn`

##### <a name="galera_package_ensure"></a>`galera_package_ensure`

Data type: `Optional[String]`

Specifies the ensure state for the galera package. Note that some vendors
do not allow installation of the wsrep-enabled MySQL/MariaDB and galera
(arbitrator) on the same server. Valid options: all values supported by
the package type. Default: `absent`

Default value: ``undef``

##### <a name="galera_package_name"></a>`galera_package_name`

Data type: `Optional[String]`

Specifies the name of the galera wsrep package to install.
Default: A vendor-, version- and OS-specific value.

Default value: ``undef``

##### <a name="galera_servers"></a>`galera_servers`

Data type: `Optional[Array]`

Specifies a list of IP addresses of the nodes in the galera cluster.
Default: `[${facts['networking']['ip']}]`

Default value: ``undef``

##### <a name="libgalera_location"></a>`libgalera_location`

Data type: `Optional[String]`

Specifies the location of the WSREP libraries.

Default value: ``undef``

##### <a name="local_ip"></a>`local_ip`

Data type: `String`

Specifies the IP address of this node to use for communications.
Default: `$networking.ip`

##### <a name="manage_additional_packages"></a>`manage_additional_packages`

Data type: `Boolean`

Specifies whether additional packages should be installed that may be
required for SST and other features. Default: `true`

##### <a name="mysql_package_name"></a>`mysql_package_name`

Data type: `Optional[String]`

Specifies the name of the server package to install.
Default: A vendor-, version- and OS-specific value.

Default value: ``undef``

##### <a name="mysql_port"></a>`mysql_port`

Data type: `Integer`

Specifies the port to use for MySQL/MariaDB. Default: `3306`

##### <a name="mysql_restart"></a>`mysql_restart`

Data type: `Boolean`

Specifies the option to pass through to `mysql::server::restart`. This can
cause issues during bootstrapping if switched on. Default: `false`

##### <a name="mysql_service_name"></a>`mysql_service_name`

Data type: `Optional[String]`

Specifies the option to pass through to `mysql::server`.
Default: A vendor-, version- and OS-specific value.

Default value: ``undef``

##### <a name="override_options"></a>`override_options`

Data type: `Hash`

Specifies options to pass to `mysql::server` class. See the puppetlabs-mysql
documentation for more information. Default: `{}`

##### <a name="override_repos"></a>`override_repos`

Data type: `Optional[Array]`

Usually the required YUM/APT repositories are automatically selected,
depending on the values of `$vendor_type` and `$vendor_version`. This
parameter will override this to provide a custom selection of repositories.

Default value: ``undef``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

Specifies the ensure state for packages. Valid options: all values supported
by the package type. Default: `installed`

##### <a name="purge_conf_dir"></a>`purge_conf_dir`

Data type: `Boolean`

Specifies the option to pass through to `mysql::server`. Default: `true`

##### <a name="root_password"></a>`root_password`

Data type: `String`

Specifies the MySQL/MariaDB root password.

##### <a name="rundir"></a>`rundir`

Data type: `String`

Specifies the rundir for the MySQL/MariaDB service.
Default: `/var/run/mysqld`

##### <a name="service_enabled"></a>`service_enabled`

Data type: `Boolean`

Specifies whether the MySQL/MariaDB service should be enabled.
Default: `true`

##### <a name="status_allow"></a>`status_allow`

Data type: `String`

Specifies the subnet or host(s) (in MySQL/MariaDB syntax) to allow status
checks from. Default: `%`

##### <a name="status_available_when_donor"></a>`status_available_when_donor`

Data type: `Integer`

Specifies whether the node will remain in the cluster when it enters donor
mode. Valid options: `0` (remove), `1` (remain). Default: `0`

##### <a name="status_available_when_readonly"></a>`status_available_when_readonly`

Data type: `Integer`

When set to 0, clustercheck will return a "503 Service Unavailable" if the
node is in the read_only state, as defined by the `read_only` MySQL/MariaDB
variable. Values other than 0 have no effect. Default: `-1`

##### <a name="status_check"></a>`status_check`

Data type: `Boolean`

Specifies whether to configure a user and script that will check the status
of the galera cluster. Default: `true`

##### <a name="status_host"></a>`status_host`

Data type: `String`

Specifies the cluster to add the cluster check user to. Default: `localhost`

##### <a name="status_log_on_failure"></a>`status_log_on_failure`

Data type: `Optional[String]`

Specifies which fields xinetd will log on failure. Default: `undef`

Default value: ``undef``

##### <a name="status_log_on_success"></a>`status_log_on_success`

Data type: `Optional[String]`

Specifies which fields xinetd will log on success. Default: `''`

Default value: ``undef``

##### <a name="status_log_on_success_operator"></a>`status_log_on_success_operator`

Data type: `String`

Specifies which operator xinetd uses to output logs on success.
Default: `=`

##### <a name="status_password"></a>`status_password`

Data type: `String`

Specifies the password of the status check user.

##### <a name="status_port"></a>`status_port`

Data type: `Integer`

Specifies the port for cluster check service. Default: `9200`

##### <a name="status_user"></a>`status_user`

Data type: `String`

Specifies the name of the user to use for status checks.
Default: `clustercheck`

##### <a name="validate_connection"></a>`validate_connection`

Data type: `Boolean`

Specifies whether the module should ensure that the cluster can accept
connections at the point where the `mysql::server` resource is marked
as complete. This is used because after returning success, the service
is still not quite ready. Default: `true`

##### <a name="vendor_type"></a>`vendor_type`

Data type: `Enum['codership', 'mariadb', 'percona']`

Specifies the galera vendor (or flavour) to use.
Valid options: codership, mariadb, percona. Default: `percona`

##### <a name="vendor_version"></a>`vendor_version`

Data type: `Optional[String]`

Specifies the galera version to use. To avoid accidential updates,
set this to the required version.
Default: A vendor- and OS-specific value. (Usually the most recent version.)

Default value: ``undef``

##### <a name="wsrep_group_comm_port"></a>`wsrep_group_comm_port`

Data type: `Integer`

Specifies the port to use for galera clustering. Default: `4567`

##### <a name="wsrep_inc_state_transfer_port"></a>`wsrep_inc_state_transfer_port`

Data type: `Integer`

Specifies the port to use for galera incremental state transfer.
Default: `4568`

##### <a name="wsrep_sst_auth"></a>`wsrep_sst_auth`

Data type: `String`

Specifies the authentication information to use for SST.
Default: `root:<%= $root_password %>`

##### <a name="wsrep_sst_method"></a>`wsrep_sst_method`

Data type: `Enum['mariabackup', 'mysqldump', 'rsync', 'skip', 'xtrabackup', 'xtrabackup-v2']`

Specifies the method to use for state snapshot transfer between nodes.
Valid options: mysqldump, rsync, skip, xtrabackup, xtrabackup-v2 (Percona).
Default: `rsync`

##### <a name="wsrep_state_transfer_port"></a>`wsrep_state_transfer_port`

Data type: `Integer`

Specifies the port to use for galera state transfer.
Default: `4444`

### <a name="galerafirewall"></a>`galera::firewall`

Open firewall ports used by galera using puppetlabs-firewall.

#### Parameters

The following parameters are available in the `galera::firewall` class:

* [`source`](#source)

##### <a name="source"></a>`source`

Data type: `Optional[String]`

Specifies the firewall source addresses to unblock. Valid options: a string. Default: `undef`

Default value: ``undef``

## Defined types

